@@ -12,7 +12,7 @@ parse.coding = function(form) {
   a = eval(parse(text = sub(nm[2], "0", rhs)))
   b = eval(parse(text = sub(nm[2], "1", rhs)))
   d = 1 / (b - a)
-  list(names = nm, const=c(center = round(-a * d, 4), divisor = round(d, 4)))
+  list(names = nm, const=c(center = signif(-a * d, 4), divisor = signif(d, 4)))
 }
 
 
